@@ -3,7 +3,7 @@ from pathlib import Path
 from click import make_pass_decorator
 from pydantic import BaseModel
 
-from delfino.constants import PackageManager
+from delfino.constants import COMMANDS_DIRECTORY_NAME, PackageManager
 from delfino.models.pyproject_toml import PyprojectToml
 
 
@@ -11,6 +11,7 @@ class AppContext(BaseModel):
     project_root: Path
     pyproject_toml: PyprojectToml
     package_manager: PackageManager
+    commands_directory: Path = Path(COMMANDS_DIRECTORY_NAME)
 
     class Config:
         arbitrary_types_allowed = True
