@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Set
+from typing import Any, Dict, List, Optional, Set, Tuple
 
 from pydantic import BaseModel, Extra, Field
 
@@ -9,17 +9,23 @@ class Dockerhub(BaseModel):
     username: str
 
 
+class Typecheck(BaseModel):
+    strict_directories: List[Path] = []
+
+
 class Delfino(BaseModel):
     sources_directory: Path = Path("src")
     tests_directory: Path = Path("tests")
     reports_directory: Path = Path("reports")
     test_types: List[str] = ["unit", "integration"]
     disable_commands: Set[str] = Field(default_factory=set)
-
+    verify_commands: Tuple[str, ...] = ("format", "lint", "typecheck", "test-all")
+    disable_pre_commit: bool = False
     dockerhub: Optional[Dockerhub] = None
-
     plugins: Dict[str, Any] = Field(default_factory=dict, description="Any additional config given by plugins.")
 
+    typecheck: Typecheck = Field(default_factory=Typecheck)
+
     class Config:
         extra = Extra.allow
 
